/*
 * @Description: 
 * @Author: luzc
 * @Date: 2021-04-12 10:45:21
 */
'use strict';

const path = require('path');
const fs = require('fs');
const getPublicUrlOrPath = require('react-dev-utils/getPublicUrlOrPath');
const merge = require('lodash.merge');

const appDirectory = fs.realpathSync(process.cwd());
const resolveApp = relativePath => path.resolve(appDirectory, relativePath);

const moduleFileExtensions = [
  'web.mjs',
  'mjs',
  'web.js',
  'js',
  'web.ts',
  'ts',
  'web.tsx',
  'tsx',
  'json',
  'web.jsx',
  'jsx',
];


const getUserConfig = () => {
  const defaultConf = {
    alias: {
      '@': resolveApp('src'),
      '@root': resolveApp('.')
    },
    addBabelPlugins: [],
    addWebpackPlugins: [],
    addModuleRules: [],
    devServer: {},
    proxy: {}
  };

  const conf = fs.existsSync(resolveApp('app.config.js'));
  if (conf) {
    const config = require(resolveApp('app.config.js'));
    return merge(defaultConf, config);
  }
  return defaultConf;
};

const appConfig = getUserConfig();


const publicUrlOrPath = getPublicUrlOrPath(
  process.env.NODE_ENV === 'development',
  appConfig.publicPath,
  process.env.PUBLIC_URL
);

const resolveModule = (resolveFn, filePath) => {
  const extension = moduleFileExtensions.find(extension =>
    fs.existsSync(resolveFn(`${filePath}.${extension}`))
  );

  if (extension) {
    return resolveFn(`${filePath}.${extension}`);
  }

  return resolveFn(`${filePath}.js`);
};

module.exports = {
  dotenv: resolveApp('.env'),
  appPath: resolveApp('.'),
  appBuild: resolveApp('dist'),
  appPublic: resolveApp('public'),
  cacheDir: resolveApp('node_modules/.cache'),
  appHtml: resolveApp('public/index.html'),
  appIndexJs: resolveModule(resolveApp, 'src/index'),
  appPackageJson: resolveApp('package.json'),
  appSrc: resolveApp('src'),
  appTsConfig: resolveApp('tsconfig.json'),
  appJsConfig: resolveApp('jsconfig.json'),
  yarnLockFile: resolveApp('yarn.lock'),
  testsSetup: resolveModule(resolveApp, 'src/setupTests'),
  proxySetup: resolveApp('src/setupProxy.js'),
  appNodeModules: resolveApp('node_modules'),
  swSrc: resolveModule(resolveApp, 'src/service-worker'),
  publicUrlOrPath,
  appConfig
};



module.exports.moduleFileExtensions = moduleFileExtensions;
