/*
 * @Description: 
 * @Author: luzc
 * @Date: 2021-04-12 10:39:04
 */
'use strict';

const fs = require('fs');
const paths = require('./paths');
const ignoredFiles = require('react-dev-utils/ignoredFiles');
const redirectServedPath = require('react-dev-utils/redirectServedPathMiddleware');
const errorOverlayMiddleware = require('react-dev-utils/errorOverlayMiddleware');
const evalSourceMapMiddleware = require('react-dev-utils/evalSourceMapMiddleware');
const noopServiceWorkerMiddleware = require('react-dev-utils/noopServiceWorkerMiddleware');

const host = process.env.HOST || '0.0.0.0';
const sockHost = process.env.WDS_SOCKET_HOST;
const sockPath = process.env.WDS_SOCKET_PATH;
const sockPort = process.env.WDS_SOCKET_PORT;

module.exports = (proxy, allowedHost) => ({
  disableHostCheck: true,
  compress: true,
  clientLogLevel: 'error',
  contentBase: paths.appPublic,
  contentBasePublicPath: paths.publicUrlOrPath,
  watchContentBase: true,
  hot: true,
  transportMode: 'ws',
  injectClient: true,
  sockHost,
  sockPath,
  sockPort,
  host,
  proxy,
  publicPath: paths.publicUrlOrPath.slice(0, -1),
  quiet: true,
  watchOptions: {
    ignored: ignoredFiles(paths.appSrc),
  },
  overlay: true,
  historyApiFallback: {
    disableDotRule: true,
    index: paths.publicUrlOrPath,
  },
  public: allowedHost,
  before(app, server) {
    app.use(evalSourceMapMiddleware(server));
    app.use(errorOverlayMiddleware())
  },
  after(app) {
    app.use(redirectServedPath(paths.publicUrlOrPath));
    app.use(noopServiceWorkerMiddleware(paths.publicUrlOrPath));
  },
})